#include <gtk/gtk.h>
#include <glade/glade.h>
#include <loudmouth/loudmouth.h>
#include <stdio.h>
#include <time.h>
#include "kf.h"
#include "jabber.h"
#include "archive.h"

static void kf_archive_real (LmMessage *msg, const gchar *jid);

/* Puts a LmMessage into archive.
 * set yours to TRUE for outcoming messages */
void kf_archive_msg (LmMessage *msg, gboolean yours) {
	LmMessageNode *node;
	const gchar *jid;
	gchar *cjid;
	gchar *stamp;

	g_return_if_fail (msg->node);

	g_print ("***\n%s\n***\n", lm_message_node_to_string (msg->node));
	if (yours)
		jid = lm_message_node_get_attribute (msg->node, "to");
	else
		jid = lm_message_node_get_attribute (msg->node, "from");

	g_return_if_fail (jid);

	cjid = g_strdup (jid);
	kf_jabber_jid_crop (cjid);

	stamp = g_strdup_printf ("%d", time (NULL));
	lm_message_node_set_attribute (msg->node, "kf:stamp", stamp);
	g_free (stamp);

	kf_archive_real (msg, cjid);

	g_free (cjid);
}

static void kf_archive_real (LmMessage *msg, const gchar *jid) {
	FILE *f;
	const gchar *path;
	gchar *filename;

	/* Let's create archive directory, if it doesn't exist */
	path = kf_config_file ("archive");
	if (!g_file_test (path, G_FILE_TEST_IS_DIR)) {
		mkdir (path, 00753);
	}

	filename = g_strdup_printf ("%s/%s.xml", path, jid);

	g_print ("path: %s, filename: %s\n", path, filename);
	f = fopen (filename, "ab");
	g_return_if_fail (f);

	if (fseek (f, -20L, SEEK_END)) {
		g_print ("AAAA");
	}

	fputs (lm_message_node_to_string (msg->node), f);
//	fputs ("</archive>\n", f);

	fclose (f);

	g_free (filename);
}
