#include <gtk/gtk.h>
#include <glade/glade.h>
#include "preferences.h"
#include "gui.h"
#include "kf.h"
#include "eggtrayicon.h"

/* Dock */
static GtkWidget *dock;
static GladeXML *dock_glade;

EggTrayIcon *egg;

/* XXX */
static gboolean    dock_button_press       (GtkWidget *widget,
                                            GdkEventButton *event,
					    gpointer user_data);
static void        dock_menu               (GtkMenuItem *menuitem,
                                            gpointer user_data);
void kf_jabber_disconnect (void);

/* Code */

void kf_dock_init (void) {
	GtkWidget *image;
	GtkWidget *eventbox;
	GtkTooltips *tooltips;

	egg = egg_tray_icon_new ("kf");

	eventbox = gtk_event_box_new ();
	gtk_widget_set_size_request (eventbox, 22, 22);
	g_signal_connect (G_OBJECT (eventbox), "button-press-event",
			G_CALLBACK (dock_button_press), NULL);

	image = gtk_image_new_from_file (kf_gui_find_file ("unavailable.png"));

	gtk_container_add (GTK_CONTAINER (egg), eventbox);
	gtk_container_add (GTK_CONTAINER (eventbox), image);

	dock = GTK_WIDGET (egg);
	g_object_set_data (G_OBJECT (dock), "image", image);

	gtk_widget_show (eventbox);
	gtk_widget_show (image);
	gtk_widget_show (GTK_WIDGET (egg));

	dock_glade = glade_xml_new (kf_gui_find_file ("dock.glade"), NULL, NULL);
	kf_signal_connect (dock_glade, "dock_online", "activate", G_CALLBACK (dock_menu), NULL);
	kf_signal_connect (dock_glade, "dock_chatty", "activate", G_CALLBACK (dock_menu), "chat");
	kf_signal_connect (dock_glade, "dock_away", "activate", G_CALLBACK (dock_menu), "away");
	kf_signal_connect (dock_glade, "dock_xa", "activate", G_CALLBACK (dock_menu), "xa");
	kf_signal_connect (dock_glade, "dock_dnd", "activate", G_CALLBACK (dock_menu), "dnd");
	kf_signal_connect (dock_glade, "dock_invisible", "activate", G_CALLBACK (dock_menu), "invisible");
	kf_signal_connect (dock_glade, "dock_disconnect", "activate", G_CALLBACK (kf_jabber_disconnect), NULL);
	kf_signal_connect (dock_glade, "dock_quit", "activate", G_CALLBACK (gtk_main_quit), NULL);

	tooltips = gtk_tooltips_new ();
	gtk_tooltips_set_tip (tooltips, eventbox, "kf", NULL);
	g_object_set_data (G_OBJECT (dock), "tooltips", tooltips);
}

void kf_dock_update_icon (gint type, gchar *status) {
	GtkWidget *image;
	GdkPixbuf *pixbuf;
	GtkTooltips *tooltips;
	gchar *text;

	image = g_object_get_data (G_OBJECT (dock), "image");
	pixbuf = kf_gui_pixmap_get_status (type);

	gtk_image_set_from_pixbuf (GTK_IMAGE (image), pixbuf);

	text = g_strdup_printf ("kf: %s (%s)", kf_jabber_presence_type_to_string (type), status);
	tooltips = g_object_get_data (G_OBJECT (dock), "tooltips");
	gtk_tooltips_set_tip (tooltips, gtk_bin_get_child (GTK_BIN (dock)), text , NULL);
	g_free (text);
}

static gboolean    dock_button_press       (GtkWidget *widget,
                                            GdkEventButton *event,
                                            gpointer user_data)
{
	if (event->type == GDK_BUTTON_PRESS && event->button == 3) {
		/* Right mouse button */
		GtkWidget *menu;

		menu = glade_xml_get_widget (dock_glade, "dock_menu");
		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
				NULL, event->button, event->time);
	} else if (event->button == 1) {
		/* Left mouse button */
		extern GladeXML *iface;
		GtkWidget *window;

		window = glade_xml_get_widget (iface, "main_window");
		if (GTK_WIDGET_VISIBLE (window)) {
			gtk_widget_hide (window);
		} else {
			gtk_widget_show (window);
		}
	}
}

/* Callback for dock menu for changing presence */
static void        dock_menu               (GtkMenuItem *menuitem,
                                            gpointer user_data) {
	kf_gui_change_status (user_data);
}
